@@ -9,11 +9,11 @@ config_dir: setup of directory ~/.pyTEMlib for custom sources and database
 import os
 import shutil
 from pkg_resources import resource_filename
+import importlib_resources
 
 config_files = ['microscopes.csv', 'edges_db.csv', 'edges_db.pkl', 'fparam.txt']
 
 data_path = resource_filename(__name__, 'data')
-print(data_path)
 if os.name == 'posix':
     config_path = os.path.join(os.path.expanduser('~'), '.TEMlib')
     os_name = 'posix'
@@ -27,7 +27,8 @@ if os.path.isdir(config_path) is False:
     os.mkdir(config_path)
 
 for file in config_files:
-    templates_file = resource_filename(__name__, 'data/'+ file)
-    config_file = os.path.join(config_path, file)
-    if os.path.isfile(config_file) is False:
-        shutil.copy(templates_file, config_file)
+    ref = importlib_resources.files('pyTEMlib') / '/'.join(['data', file])
+    with importlib_resources.as_file(ref) as templates_file:
+        config_file = os.path.join(config_path, file)
+        if os.path.isfile(config_file) is False:
+            shutil.copy(templates_file, config_file)
